@@ -3,6 +3,7 @@ mod alpm;
 mod be_local;
 mod be_pkg;
 mod be_sync;
+mod cb;
 mod conflict;
 mod db;
 mod deps;
@@ -11,7 +12,9 @@ mod error;
 mod filelist;
 mod handle;
 mod list;
-mod macros;
+mod log;
+#[cfg(feature = "mtree")]
+mod mtree;
 mod package;
 mod remove;
 mod signing;
@@ -20,6 +23,7 @@ mod trans;
 mod types;
 mod util;
 mod utils;
+
 mod version;
 
 pub use crate::add::*;
@@ -27,6 +31,7 @@ pub use crate::alpm::*;
 pub use crate::be_local::*;
 pub use crate::be_pkg::*;
 pub use crate::be_sync::*;
+pub use crate::cb::*;
 pub use crate::conflict::*;
 pub use crate::db::*;
 pub use crate::deps::*;
@@ -35,7 +40,8 @@ pub use crate::error::*;
 pub use crate::filelist::*;
 pub use crate::handle::*;
 pub use crate::list::*;
-pub use crate::macros::*;
+#[cfg(feature = "mtree")]
+pub use crate::mtree::*;
 pub use crate::package::*;
 pub use crate::remove::*;
 pub use crate::signing::*;
@@ -44,4 +50,3 @@ pub use crate::trans::*;
 pub use crate::types::*;
 pub use crate::util::*;
 pub use crate::version::*;
-pub use alpm_sys;
