@@ -79,8 +79,6 @@ impl fmt::Debug for PgpKey {
 }
 
 impl PgpKey {
-    //TODO: what is data?
-
     pub fn fingerprint(&self) -> &str {
         unsafe { from_cstr(self.inner.fingerprint) }
     }
@@ -90,11 +88,11 @@ impl PgpKey {
     }
 
     pub fn name(&self) -> &str {
-        unsafe { from_cstr(self.inner.name) }
+        unsafe { from_cstr_optional2(self.inner.name) }
     }
 
     pub fn email(&self) -> &str {
-        unsafe { from_cstr(self.inner.email) }
+        unsafe { from_cstr_optional2(self.inner.email) }
     }
 
     pub fn created(&self) -> i64 {
@@ -118,6 +116,7 @@ impl PgpKey {
     }
 }
 
+#[repr(transparent)]
 pub struct SigResult {
     inner: alpm_sigresult_t,
 }
@@ -181,7 +180,13 @@ impl SigList {
     }
 
     pub fn results(&self) -> &[SigResult] {
-        unsafe { slice::from_raw_parts(self.inner.results as *const SigResult, self.inner.count) }
+        if self.inner.results.is_null() {
+            unsafe { slice::from_raw_parts(1 as *const SigResult, 0) }
+        } else {
+            unsafe {
+                slice::from_raw_parts(self.inner.results as *const SigResult, self.inner.count)
+            }
+        }
     }
 }
 
